==> GeneTraffic_1.6.0.tar.gz: GeneTraffic/R/GTLoadExpression.R <==
#
# eset <- GTLoadExpression(filename="Project.zip")
#

"GTLoadExpression" <- function(filename = "Project.zip") {
     
 fType <- zip.file.extract("ProjectType.xls",filename)
 if(file.exists(fType)) {
    
    Type <- readLines(fType)
    if( Type == "One color project.") {
	
	require(affy)
	fMIAME <- zip.file.extract("MIAME_Sample_Annotation.xls",filename)
	MIAME <- read.csv(file = fMIAME, sep="\t")
	NumLayoutTypes = length(unique(MIAME[,5]))
    
	fProbeSet <- zip.file.extract("Probe_Set_Intensity_1.xls",filename)
	ProbeSet <- read.table(file = fProbeSet, header=TRUE, sep="\t") 
	mat <- data.matrix(ProbeSet)
	matr <- mat[,3:ncol(mat)]
	eset <- new('exprSet', exprs = matr)
	geneNames(eset) <- ProbeSet[,2]

	if( NumLayoutTypes > 1) {
	    aeset <- list(eset)
	    for (i in (2:NumLayoutTypes)) {
    
		file <- paste("Probe_Set_Intensity_",i,".xls",sep="")
		fProbeSet <- zip.file.extract(file,filename)
		ProbeSet <- read.table(file = fProbeSet, header=TRUE, sep="\t") 
		mat <- data.matrix(ProbeSet)
		matr <- mat[,3:ncol(mat)]
		eset <- new('exprSet', exprs = matr)
		geneNames(eset) <- ProbeSet[,2]
		aeset[[i]] <- eset
	    }
	    aeset
	} else {
	    eset
	}
    } else {
	if( Type == "Two color project.") {
	    
	    require(marray)
	    fMIAME <- zip.file.extract("MIAME_Sample_Annotation.xls",filename)
	    MIAME <- read.csv(file = fMIAME, sep="\t")
	    NumLayoutTypes = length(unique(MIAME[,3]))

	    fProbeSetRf <- zip.file.extract("Spot_LEX_E_Foreground_1.xls",filename)
	    ProbeSetRf <- read.table(file = fProbeSetRf, header=TRUE, sep="\t") 
	    matRf <- data.matrix(ProbeSetRf)
	    matrRf <- matRf[,3:ncol(matRf)]
	
	    fProbeSetRb <- zip.file.extract("Spot_LEX_E_Background_1.xls",filename)
	    ProbeSetRb <- read.table(file = fProbeSetRb, header=TRUE, sep="\t") 
	    matRb <- data.matrix(ProbeSetRb)
	    matrRb <- matRb[,3:ncol(matRb)]

	    fProbeSetGf <- zip.file.extract("Spot_LEX_R_Foreground_1.xls",filename)
	    ProbeSetGf <- read.table(file = fProbeSetGf, header=TRUE, sep="\t") 
	    matGf <- data.matrix(ProbeSetGf)
	    matrGf <- matGf[,3:ncol(matGf)]

	    fProbeSetGb <- zip.file.extract("Spot_LEX_R_Background_1.xls",filename)
	    ProbeSetGb <- read.table(file = fProbeSetGb, header=TRUE, sep="\t") 
	    matGb <- data.matrix(ProbeSetGb)
	    matrGb <- matGb[,3:ncol(matGb)]

	    gn <- new('marrayInfo',maInfo=data.frame(ProbeSetRf[,2]))
	    eset <- new ('marrayRaw',maRf=matrRf,maGf=matrGf,maRb=matrRb,maGb=matrGb,maGnames=gn)
	    
	    if( NumLayoutTypes > 1) {
		aeset <- list(eset)
		for (i in (2:NumLayoutTypes)) {

		    fileRf <- paste("Spot_LEX_E_Foreground_",i,".xls",sep="")
		    fProbeSetRf <- zip.file.extract(fileRf,filename)
		    ProbeSetRf <- read.table(file = fProbeSetRf, header=TRUE, sep="\t") 
		    matRf <- data.matrix(ProbeSetRf)
		    matrRf <- matRf[,3:ncol(matRf)]
	
		    fileRb <- paste("Spot_LEX_E_Background_",i,".xls",sep="")
		    fProbeSetRb <- zip.file.extract(fileRb,filename)
		    ProbeSetRb <- read.table(file = fProbeSetRb, header=TRUE, sep="\t") 
		    matRb <- data.matrix(ProbeSetRb)
		    matrRb <- matRb[,3:ncol(matRb)]

		    fileGf <- paste("Spot_LEX_R_Foreground_",i,".xls",sep="")
		    fProbeSetGf <- zip.file.extract(fileGf,filename)
		    ProbeSetGf <- read.table(file = fProbeSetGf, header=TRUE, sep="\t") 
		    matGf <- data.matrix(ProbeSetGf)
		    matrGf <- matGf[,3:ncol(matGf)]

		    fileGb <- paste("Spot_LEX_R_Background_",i,".xls",sep="")
		    fProbeSetGb <- zip.file.extract(fileGb,filename)
    		    ProbeSetGb <- read.table(file = fProbeSetGb, header=TRUE, sep="\t") 
		    matGb <- data.matrix(ProbeSetGb)
		    matrGb <- matGb[,3:ncol(matGb)]

		    gn <- new('marrayInfo',maInfo=data.frame(ProbeSetRf[,2]))
		    eset <- new ('marrayRaw',maRf=matrRf,maGf=matrGf,maRb=matrRb,maGb=matrGb,maGnames=gn)
		    aeset[[i]] <- eset
		}
		aeset
	    } else {
		eset
	    }
	} 
    }
 } else {
    "Cannot read project type. Project.zip summary file has to be generated on a Genetraffic server later than 3.0. Please update your summary file."
 }
}

==> GeneTraffic_1.16.0.tar.gz: GeneTraffic/R/GTLoadExpression.R <==
#
# eset <- GTLoadExpression(filename="Project.zip")
#

"GTLoadExpression" <- function(filename = "Project.zip") {
     
 fType <- zip.file.extract("ProjectType.xls",filename)
 if(file.exists(fType)) {
    
    Type <- readLines(fType)
    if(Type == "One color project.") {
	
	require(affy)
	fMIAME <- zip.file.extract("MIAME_Sample_Annotation.xls",filename)
	MIAME <- read.csv(file = fMIAME, sep="\t")
	NumLayoutTypes = length(unique(MIAME[,5]))
    
	fProbeSet <- zip.file.extract("Probe_Set_Intensity_1.xls",filename)
	ProbeSet <- read.table(file = fProbeSet, header=TRUE, sep="\t") 
	mat <- data.matrix(ProbeSet)
	matr <- mat[,3:ncol(mat)]
	eset <- new('ExpressionSet', exprs = matr)
	featureNames(eset) <- ProbeSet[,2]

	if(NumLayoutTypes > 1) {
	    aeset <- list(eset)
	    for (i in (2:NumLayoutTypes)) {
    
		file <- paste("Probe_Set_Intensity_",i,".xls",sep="")
		fProbeSet <- zip.file.extract(file,filename)
		ProbeSet <- read.table(file = fProbeSet, header=TRUE, sep="\t") 
		mat <- data.matrix(ProbeSet)
		matr <- mat[,3:ncol(mat)]
		eset <- new('ExpressionSet', exprs = matr)
		featureNames(eset) <- ProbeSet[,2]
		aeset[[i]] <- eset
	    }
	    aeset
	} else {
	    eset
	}
    } else {
	if( Type == "Two color project.") {
	    
	    require(marray)
	    fMIAME <- zip.file.extract("MIAME_Sample_Annotation.xls",filename)
	    MIAME <- read.csv(file = fMIAME, sep="\t")
	    NumLayoutTypes = length(unique(MIAME[,3]))

	    fProbeSetRf <- zip.file.extract("Spot_LEX_E_Foreground_1.xls",filename)
	    ProbeSetRf <- read.table(file = fProbeSetRf, header=TRUE, sep="\t") 
	    matRf <- data.matrix(ProbeSetRf)
	    matrRf <- matRf[,3:ncol(matRf)]
	
	    fProbeSetRb <- zip.file.extract("Spot_LEX_E_Background_1.xls",filename)
	    ProbeSetRb <- read.table(file = fProbeSetRb, header=TRUE, sep="\t") 
	    matRb <- data.matrix(ProbeSetRb)
	    matrRb <- matRb[,3:ncol(matRb)]

	    fProbeSetGf <- zip.file.extract("Spot_LEX_R_Foreground_1.xls",filename)
	    ProbeSetGf <- read.table(file = fProbeSetGf, header=TRUE, sep="\t") 
	    matGf <- data.matrix(ProbeSetGf)
	    matrGf <- matGf[,3:ncol(matGf)]

	    fProbeSetGb <- zip.file.extract("Spot_LEX_R_Background_1.xls",filename)
	    ProbeSetGb <- read.table(file = fProbeSetGb, header=TRUE, sep="\t") 
	    matGb <- data.matrix(ProbeSetGb)
	    matrGb <- matGb[,3:ncol(matGb)]

	    gn <- new('marrayInfo',maInfo=data.frame(ProbeSetRf[,2]))
	    eset <- new ('marrayRaw',maRf=matrRf,maGf=matrGf,maRb=matrRb,maGb=matrGb,maGnames=gn)
	    
	    if( NumLayoutTypes > 1) {
		aeset <- list(eset)
		for (i in (2:NumLayoutTypes)) {

		    fileRf <- paste("Spot_LEX_E_Foreground_",i,".xls",sep="")
		    fProbeSetRf <- zip.file.extract(fileRf,filename)
		    ProbeSetRf <- read.table(file = fProbeSetRf, header=TRUE, sep="\t") 
		    matRf <- data.matrix(ProbeSetRf)
		    matrRf <- matRf[,3:ncol(matRf)]
	
		    fileRb <- paste("Spot_LEX_E_Background_",i,".xls",sep="")
		    fProbeSetRb <- zip.file.extract(fileRb,filename)
		    ProbeSetRb <- read.table(file = fProbeSetRb, header=TRUE, sep="\t") 
		    matRb <- data.matrix(ProbeSetRb)
		    matrRb <- matRb[,3:ncol(matRb)]

		    fileGf <- paste("Spot_LEX_R_Foreground_",i,".xls",sep="")
		    fProbeSetGf <- zip.file.extract(fileGf,filename)
		    ProbeSetGf <- read.table(file = fProbeSetGf, header=TRUE, sep="\t") 
		    matGf <- data.matrix(ProbeSetGf)
		    matrGf <- matGf[,3:ncol(matGf)]

		    fileGb <- paste("Spot_LEX_R_Background_",i,".xls",sep="")
		    fProbeSetGb <- zip.file.extract(fileGb,filename)
    		    ProbeSetGb <- read.table(file = fProbeSetGb, header=TRUE, sep="\t") 
		    matGb <- data.matrix(ProbeSetGb)
		    matrGb <- matGb[,3:ncol(matGb)]

		    gn <- new('marrayInfo',maInfo=data.frame(ProbeSetRf[,2]))
		    eset <- new ('marrayRaw',maRf=matrRf,maGf=matrGf,maRb=matrRb,maGb=matrGb,maGnames=gn)
		    aeset[[i]] <- eset
		}
		aeset
	    } else {
		eset
	    }
	} 
    }
 } else {
    "Cannot read project type. Project.zip summary file has to be generated on a Genetraffic server later than 3.0. Please update your summary file."
 }
}
